@@ -2,10 +2,14 @@
 
 from babel import Locale, UnknownLocaleError
 from django.utils.translation import get_language
+from threading import local
+
 try:
-    from threading import local
+    from django.utils.deprecation import MiddlewareMixin
 except ImportError:
-    from django.utils._threading_local import local
+    # Not required for Django <= 1.9, see:
+    # https://docs.djangoproject.com/en/1.10/topics/http/middleware/#upgrading-pre-django-1-10-style-middleware
+    MiddlewareMixin = object
 
 
 __all__ = ['get_current_locale', 'LocaleMiddleware']
@@ -22,7 +26,7 @@ def get_current_locale():
     return getattr(_thread_locals, 'locale', None)
 
 
-class LocaleMiddleware(object):
+class LocaleMiddleware(MiddlewareMixin):
 
     """Simple Django middleware that makes available a Babel `Locale` object
     via the `request.locale` attribute.
